@@ -7,6 +7,7 @@
 //! use thumbnailer::{create_thumbnails, Thumbnail, ThumbnailSize};
 //! use std::fs::File;
 //! use std::io::BufReader;
+//! use std::io::Cursor;
 //!
 //! fn main() {
 //!     let file = File::open("tests/assets/test.png").unwrap();
@@ -14,7 +15,7 @@
 //!     let mut  thumbnails = create_thumbnails(reader, mime::IMAGE_PNG, [ThumbnailSize::Small, ThumbnailSize::Medium]).unwrap();
 //!     
 //!     let thumbnail = thumbnails.pop().unwrap();
-//!     let mut buf = Vec::new();
+//!     let mut buf = Cursor::new(Vec::new());
 //!     thumbnail.write_png(&mut buf).unwrap();
 //! }
 //! ```
@@ -22,7 +23,7 @@
 use crate::error::ThumbResult;
 use image;
 use image::imageops::FilterType;
-use image::{DynamicImage, ImageOutputFormat};
+use image::{DynamicImage, GenericImageView, ImageOutputFormat};
 use mime::Mime;
 use rayon::prelude::*;
 use std::io::{BufRead, Seek, Write};
@@ -41,7 +42,7 @@ pub struct Thumbnail {
 
 impl Thumbnail {
     /// Writes the bytes of the image in a png format
-    pub fn write_png<W: Write>(self, writer: &mut W) -> ThumbResult<()> {
+    pub fn write_png<W: Write + Seek>(self, writer: &mut W) -> ThumbResult<()> {
         let image = DynamicImage::ImageRgba8(self.inner.into_rgba8());
         image.write_to(writer, ImageOutputFormat::Png)?;
 
@@ -49,12 +50,17 @@ impl Thumbnail {
     }
 
     /// Writes the bytes of the image in a jpeg format
-    pub fn write_jpeg<W: Write>(self, writer: &mut W, compression: u8) -> ThumbResult<()> {
+    pub fn write_jpeg<W: Write + Seek>(self, writer: &mut W, compression: u8) -> ThumbResult<()> {
         let image = DynamicImage::ImageRgb8(self.inner.into_rgb8());
         image.write_to(writer, ImageOutputFormat::Jpeg(compression))?;
 
         Ok(())
     }
+
+    /// Returns the size of the thumbnail as width,  height
+    pub fn size(&self) -> (u32, u32) {
+        self.inner.dimensions()
+    }
 }
 
 /// Creates thumbnails of the requested sizes for the given reader providing the content as bytes and
@@ -79,7 +85,7 @@ fn resize_images(image: DynamicImage, sizes: &[ThumbnailSize]) -> Vec<DynamicIma
         .into_par_iter()
         .map(|size| {
             let (width, height) = size.dimensions();
-            image.resize(width, height, FilterType::Nearest)
+            image.resize(width, height, FilterType::Lanczos3)
         })
         .collect()
 }
